==> ktp-text-ui-0.5.80.tar.bz2: ktp-text-ui-0.5.80/filters/texttospeech/ktptextui_message_filter_tts.desktop.cmake <==
[Desktop Entry]
Name=Text To Speech
Name[cs]=Hlasová syntéza
Name[da]=Tekst-til-tale
Name[de]=Sprachausgabe
Name[el]=Μετατροπή κειμένου σε ομιλία
Name[es]=Texto a locución
Name[et]=Teksti ettelugemine
Name[fi]=Teksti puheeksi
Name[fr]=Synthèse vocale
Name[gl]=Texto para voz
Name[hu]=Szövegfelolvasó
Name[it]=Sintesi vocale
Name[lt]=Tekstas balsu
Name[nb]=Tekst til tale
Name[nl]=Tekst-naar-spraak
Name[pl]=Tekst-na-mowę
Name[pt]=Texto para Fala
Name[pt_BR]=Sintetizador de voz
Name[ro]=Text-în-vorbire
Name[ru]=Синтез речи
Name[sk]=Text na reč
Name[sl]=Besedilo v govor
Name[sr]=Текст у говор
Name[sr@ijekavian]=Текст у говор
Name[sr@ijekavianlatin]=Tekst u govor
Name[sr@latin]=Tekst u govor
Name[sv]=Text till tal
Name[tr]=Metin Okuma
Name[uk]=Синтез мовлення з тексту
Name[wa]=Tecse-viè-vwès
Name[x-test]=xxText To Speechxx
Name[zh_CN]=文本到语音
Name[zh_TW]=文字轉語音
Encoding=UTF-8
Comment=Read out incoming messages using text-to-speech service
Comment[cs]=Předčítat příchozí zprávy pomocí služby hlasové syntézy
Comment[da]=Læs indkommende beskeder op med tekst-til-tale-tjenesten
Comment[de]=Eingehende Nachrichten mit dem Sprachausgabedienst volesen
Comment[el]=Ανάγνωση εισερχόμενων μηνυμάτων με χρήση υπηρεσίας μετατροπή-κειμένου-σε-ομιλία
Comment[es]=Leer los mensajes entrantes utilizando el servicio texto-a-locución
Comment[et]=Sisenevate sõnumite ettelugemine teksti ettelugemise teenuse abil
Comment[fi]=Lue saapuvat viestit ääneen käyttäen puhesyntetisaattoripalvelua
Comment[fr]=Lire à haute voix les messages entrants à l'aide du service de synthèse vocale
Comment[gl]=Ler en alto as mensaxes entrantes co servizo de texto para voz.
Comment[hu]=Bejövő üzenetek felolvasása a szövegfelolvasó szolgáltatás használatával
Comment[it]=Leggi i messaggi in arrivo usando il servizio di sintesi vocale
Comment[nb]=Les opp innkommend meldinger med tekst-til-tale-tjeneste
Comment[nl]=Spreek het inkomende bericht uit met de tekst-tot-spraak-dienst
Comment[pl]=Odczytuj przychodzące wiadomości używając usługi tekstu-na-mowę
Comment[pt]=Ler as mensagens recebidas com o serviço de texto-para-fala
Comment[pt_BR]=Ler as mensagens recebidas usando o serviço de sintetizador de voz
Comment[ro]=Citește mesajele de intrare folosind serviciul de text-în-vorbire
Comment[ru]=Читать входящие сообщения с помощью службы синтеза речи
Comment[sk]=Čítať prichádzajúce správy pomocou služby text na reč
Comment[sl]=Preberi dohodna sporočila z uporabo storitve besedilo v govor
Comment[sr]=Ишчитава долазне поруке преко сервиса за текст‑у‑говор
Comment[sr@ijekavian]=Ишчитава долазне поруке преко сервиса за текст‑у‑говор
Comment[sr@ijekavianlatin]=Iščitava dolazne poruke preko servisa za tekst‑u‑govor
Comment[sr@latin]=Iščitava dolazne poruke preko servisa za tekst‑u‑govor
Comment[sv]=Läs upp inkommande meddelande med text-till-tal-tjänsten
Comment[tr]=Metin okuma hizmeti ile gelen mesajları seslendir
Comment[uk]=Читати вхідні повідомлення за допомогою служби синтезу мовлення з тексту
Comment[wa]=Lére les messaedjes intrants tot s' siervant do siervice di tecse-viè-vwès
Comment[x-test]=xxRead out incoming messages using text-to-speech servicexx
Comment[zh_CN]=使用语音合成服务来朗读收到的消息
Comment[zh_TW]=將進來的訊息用文字轉語音的服務唸出來
Type=Service
ServiceTypes=KTpTextUi/MessageFilter
X-KDE-Library=ktptextui_message_filter_tts
X-KDE-PluginInfo-Author=David Edmundson
X-KDE-PluginInfo-Email=davidedmundson@kde.org
X-KDE-PluginInfo-Name=tts
X-KDE-PluginInfo-Version=@KTP_TEXT_UI_VERSION@
X-KDE-PluginInfo-Website=http://community.kde.org/KTp
X-KDE-PluginInfo-License=LGPL
X-KDE-PluginInfo-EnabledByDefault=false
X-KTp-PluginInfo-Version=@KTP_MESSAGE_FILTER_FRAMEWORK_VERSION@

==> ktp-text-ui-0.6.0.tar.bz2: ktp-text-ui-0.6.0/filters/texttospeech/ktptextui_message_filter_tts.desktop.cmake <==
[Desktop Entry]
Name=Text To Speech
Name[bs]=Tekst u govor
Name[ca]=Text a veu
Name[cs]=Hlasová syntéza
Name[da]=Tekst-til-tale
Name[de]=Sprachausgabe
Name[el]=Μετατροπή κειμένου σε ομιλία
Name[es]=Texto a locución
Name[et]=Teksti ettelugemine
Name[fi]=Teksti puheeksi
Name[fr]=Synthèse vocale
Name[gl]=Texto para voz
Name[hu]=Szövegfelolvasó
Name[ia]=Ab texto a parola
Name[it]=Sintesi vocale
Name[kk]=Мәтінді дауыстап оқу
Name[lt]=Tekstas balsu
Name[mr]=पाठ्य-ते-भाष्य
Name[nb]=Tekst til tale
Name[nl]=Tekst-naar-spraak
Name[pl]=Tekst-na-mowę
Name[pt]=Texto para Fala
Name[pt_BR]=Sintetizador de voz
Name[ro]=Text-în-vorbire
Name[ru]=Синтез речи
Name[sk]=Text na reč
Name[sl]=Besedilo v govor
Name[sr]=Текст у говор
Name[sr@ijekavian]=Текст у говор
Name[sr@ijekavianlatin]=Tekst u govor
Name[sr@latin]=Tekst u govor
Name[sv]=Text till tal
Name[tr]=Metin Okuma
Name[uk]=Синтез мовлення з тексту
Name[wa]=Tecse-viè-vwès
Name[x-test]=xxText To Speechxx
Name[zh_CN]=文本到语音
Name[zh_TW]=文字轉語音
Encoding=UTF-8
Comment=Read out incoming messages using text-to-speech service
Comment[bs]=Čitaj ulazne poruke pomoću usluge konverzije teksta u govor
Comment[ca]=Llegeix els missatges entrats utilitzant el servei de text a veu
Comment[cs]=Předčítat příchozí zprávy pomocí služby hlasové syntézy
Comment[da]=Læs indkommende beskeder op med tekst-til-tale-tjenesten
Comment[de]=Eingehende Nachrichten mit dem Sprachausgabedienst volesen
Comment[el]=Ανάγνωση εισερχόμενων μηνυμάτων με χρήση υπηρεσίας μετατροπή-κειμένου-σε-ομιλία
Comment[es]=Leer los mensajes entrantes utilizando el servicio texto-a-locución
Comment[et]=Sisenevate sõnumite ettelugemine teksti ettelugemise teenuse abil
Comment[fi]=Lue saapuvat viestit ääneen käyttäen puhesyntetisaattoripalvelua
Comment[fr]=Lire à haute voix les messages entrants à l'aide du service de synthèse vocale
Comment[gl]=Ler en alto as mensaxes entrantes co servizo de texto para voz.
Comment[hu]=Bejövő üzenetek felolvasása a szövegfelolvasó szolgáltatás használatával
Comment[ia]=Lege in alte voce messages per usar le servicio de text-to-speech (ab texto a parola)
Comment[it]=Leggi i messaggi in arrivo usando il servizio di sintesi vocale
Comment[kk]=Келген хабарламаларды мәтінді дауыстап оқу қызметі көмегімен оқу
Comment[nb]=Les opp innkommend meldinger med tekst-til-tale-tjeneste
Comment[nl]=Spreek het inkomende bericht uit met de tekst-tot-spraak-dienst
Comment[pl]=Odczytuj przychodzące wiadomości używając usługi tekstu-na-mowę
Comment[pt]=Ler as mensagens recebidas com o serviço de texto-para-fala
Comment[pt_BR]=Ler as mensagens recebidas usando o serviço de sintetizador de voz
Comment[ro]=Citește mesajele de intrare folosind serviciul de text-în-vorbire
Comment[ru]=Читать входящие сообщения с помощью службы синтеза речи
Comment[sk]=Čítať prichádzajúce správy pomocou služby text na reč
Comment[sl]=Preberi dohodna sporočila z uporabo storitve besedilo v govor
Comment[sr]=Ишчитава долазне поруке преко сервиса за текст‑у‑говор
Comment[sr@ijekavian]=Ишчитава долазне поруке преко сервиса за текст‑у‑говор
Comment[sr@ijekavianlatin]=Iščitava dolazne poruke preko servisa za tekst‑u‑govor
Comment[sr@latin]=Iščitava dolazne poruke preko servisa za tekst‑u‑govor
Comment[sv]=Läs upp inkommande meddelande med text-till-tal-tjänsten
Comment[tr]=Metin okuma hizmeti ile gelen mesajları seslendir
Comment[uk]=Читати вхідні повідомлення за допомогою служби синтезу мовлення з тексту
Comment[wa]=Lére les messaedjes intrants tot s' siervant do siervice di tecse-viè-vwès
Comment[x-test]=xxRead out incoming messages using text-to-speech servicexx
Comment[zh_CN]=使用语音合成服务来朗读收到的消息
Comment[zh_TW]=將進來的訊息用文字轉語音的服務唸出來
Type=Service
ServiceTypes=KTpTextUi/MessageFilter
X-KDE-Library=ktptextui_message_filter_tts
X-KDE-PluginInfo-Author=David Edmundson
X-KDE-PluginInfo-Email=davidedmundson@kde.org
X-KDE-PluginInfo-Name=tts
X-KDE-PluginInfo-Version=@KTP_TEXT_UI_VERSION@
X-KDE-PluginInfo-Website=http://community.kde.org/KTp
X-KDE-PluginInfo-License=LGPL
X-KDE-PluginInfo-EnabledByDefault=false
X-KTp-PluginInfo-Version=@KTP_MESSAGE_FILTER_FRAMEWORK_VERSION@
